[PATCH obv] cli-script.c: Fix read_next_line's comment

Simon Marchi simon.marchi@ericsson.com
Mon Sep 28 22:38:00 GMT 2015


It seems obvious to me that stdout should in fact be stdin.

gdb/ChangeLog:

	* cli/cli-script.c (read_next_line): Fix stdout -> stdout in
	comment.
---
 gdb/ChangeLog        | 5 +++++
 gdb/cli/cli-script.c | 4 ++--
 2 files changed, 7 insertions(+), 2 deletions(-)

diff --git a/gdb/ChangeLog b/gdb/ChangeLog
index 3d2c478..54d6054 100644
--- a/gdb/ChangeLog
+++ b/gdb/ChangeLog
@@ -1,3 +1,8 @@
+2015-09-28  Simon Marchi  <simon.marchi@ericsson.com>
+
+	* cli/cli-script.c (read_next_line): Fix stdout -> stdout in
+	comment.
+
 2015-09-28  Doug Evans  <dje@google.com>
 
 	* MAINTAINERS: Add Iain Buclaw as D language maintainer.
diff --git a/gdb/cli/cli-script.c b/gdb/cli/cli-script.c
index 6a3c068..4d35db9 100644
--- a/gdb/cli/cli-script.c
+++ b/gdb/cli/cli-script.c
@@ -924,9 +924,9 @@ realloc_body_list (struct command_line *command, int new_length)
   command->body_count = new_length;
 }
 
 /* Read next line from stdout.  Passed to read_command_line_1 and
    recurse_read_control_structure whenever we need to read commands
-   from stdout.  */
+   from stdin.  */
 
 static char *
 read_next_line (void)
@@ -924,9 +924,9 @@ realloc_body_list (struct command_line *command, int new_length)
 }
 
-/* Read next line from stdout.  Passed to read_command_line_1 and
+/* Read next line from stdin.  Passed to read_command_line_1 and
    recurse_read_control_structure whenever we need to read commands
-- 
2.5.1



More information about the Gdb-patches mailing list